@@ -108,6 +108,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 Config {
                     google_application_credentials: env::var("GOOGLE_APPLICATION_CREDENTIALS").unwrap(),
                     payment_processing_topic: env::var("PAYMENT_PROCESSING_TOPIC").unwrap(),
+                    checkout_completion_topic: env::var("CHECKOUT_COMPLETION_TOPIC").unwrap(),
                 }
             }
 
@@ -440,7 +441,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let config = checkout_server::get_config();
 
-                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone()).await.map_err(|_| checkout_server::Error {
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone(), config.checkout_completion_topic.clone()).await.map_err(|_| checkout_server::Error {
                     code: "500".to_string(),
                     message: "failed to create internal context".to_string(),
                 })?;
